package com.bonus.material.plan.service.impl;

import java.util.List;
import com.bonus.common.core.exception.ServiceException;
import com.bonus.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.material.plan.mapper.PlanNeedInfoMapper;
import com.bonus.material.plan.domain.PlanNeedInfo;
import com.bonus.material.plan.service.IPlanNeedInfoService;

/**
 * 年度计划Service业务层处理
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Service
public class PlanNeedInfoServiceImpl implements IPlanNeedInfoService {
    @Autowired
    private PlanNeedInfoMapper planNeedInfoMapper;

    /**
     * 查询年度计划
     * 
     * @param planId 年度计划主键
     * @return 年度计划
     */
    @Override
    public PlanNeedInfo selectPlanNeedInfoByPlanId(Long planId) {
        return planNeedInfoMapper.selectPlanNeedInfoByPlanId(planId);
    }

    /**
     * 查询年度计划列表
     * 
     * @param planNeedInfo 年度计划
     * @return 年度计划
     */
    @Override
    public List<PlanNeedInfo> selectPlanNeedInfoList(PlanNeedInfo planNeedInfo) {
        return planNeedInfoMapper.selectPlanNeedInfoList(planNeedInfo);
    }

    /**
     * 新增年度计划
     * 
     * @param planNeedInfo 年度计划
     * @return 结果
     */
    @Override
    public int insertPlanNeedInfo(PlanNeedInfo planNeedInfo) {
        planNeedInfo.setCreateTime(DateUtils.getNowDate());
        try {
            return planNeedInfoMapper.insertPlanNeedInfo(planNeedInfo);
        } catch (Exception e) {
            throw new ServiceException("错误信息描述");
        }
    }

    /**
     * 修改年度计划
     * 
     * @param planNeedInfo 年度计划
     * @return 结果
     */
    @Override
    public int updatePlanNeedInfo(PlanNeedInfo planNeedInfo) {
        planNeedInfo.setUpdateTime(DateUtils.getNowDate());
        try {
            return planNeedInfoMapper.updatePlanNeedInfo(planNeedInfo);
        } catch (Exception e) {
            throw new ServiceException("错误信息描述");
        }
    }

    /**
     * 批量删除年度计划
     * 
     * @param planIds 需要删除的年度计划主键
     * @return 结果
     */
    @Override
    public int deletePlanNeedInfoByPlanIds(Long[] planIds) {
        return planNeedInfoMapper.deletePlanNeedInfoByPlanIds(planIds);
    }

    /**
     * 删除年度计划信息
     * 
     * @param planId 年度计划主键
     * @return 结果
     */
    @Override
    public int deletePlanNeedInfoByPlanId(Long planId) {
        return planNeedInfoMapper.deletePlanNeedInfoByPlanId(planId);
    }
}
