package com.bonus.material.plan.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.plan.domain.PlanNeedInfo;
import com.bonus.material.plan.service.IPlanNeedInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 年度计划Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "年度计划接口")
@RestController
@RequestMapping("/plan_need_info")
public class PlanNeedInfoController extends BaseController {
    @Autowired
    private IPlanNeedInfoService planNeedInfoService;

    /**
     * 查询年度计划列表
     */
    @ApiOperation(value = "查询年度计划列表")
    @RequiresPermissions("plan:info:list")
    @GetMapping("/list")
    public TableDataInfo list(PlanNeedInfo planNeedInfo) {
        startPage();
        List<PlanNeedInfo> list = planNeedInfoService.selectPlanNeedInfoList(planNeedInfo);
        return getDataTable(list);
    }

    /**
     * 导出年度计划列表
     */
    @ApiOperation(value = "导出年度计划列表")
    @PreventRepeatSubmit
    @RequiresPermissions("plan:info:export")
    @SysLog(title = "年度计划", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出年度计划")
    @PostMapping("/export")
    public void export(HttpServletResponse response, PlanNeedInfo planNeedInfo) {
        List<PlanNeedInfo> list = planNeedInfoService.selectPlanNeedInfoList(planNeedInfo);
        ExcelUtil<PlanNeedInfo> util = new ExcelUtil<PlanNeedInfo>(PlanNeedInfo.class);
        util.exportExcel(response, list, "年度计划数据");
    }

    /**
     * 获取年度计划详细信息
     */
    @ApiOperation(value = "获取年度计划详细信息")
    @RequiresPermissions("plan:info:query")
    @GetMapping(value = "/{planId}")
    public AjaxResult getInfo(@PathVariable("planId") Long planId) {
        return success(planNeedInfoService.selectPlanNeedInfoByPlanId(planId));
    }

    /**
     * 新增年度计划
     */
    @ApiOperation(value = "新增年度计划")
    @PreventRepeatSubmit
    @RequiresPermissions("plan:info:add")
    @SysLog(title = "年度计划", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增年度计划")
    @PostMapping
    public AjaxResult add(@RequestBody PlanNeedInfo planNeedInfo) {
        try {
            return toAjax(planNeedInfoService.insertPlanNeedInfo(planNeedInfo));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改年度计划
     */
    @ApiOperation(value = "修改年度计划")
    @PreventRepeatSubmit
    @RequiresPermissions("plan:info:edit")
    @SysLog(title = "年度计划", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改年度计划")
    @PutMapping
    public AjaxResult edit(@RequestBody PlanNeedInfo planNeedInfo) {
        try {
            return toAjax(planNeedInfoService.updatePlanNeedInfo(planNeedInfo));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除年度计划
     */
    @ApiOperation(value = "删除年度计划")
    @PreventRepeatSubmit
    @RequiresPermissions("plan:info:remove")
    @SysLog(title = "年度计划", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除年度计划")
	@DeleteMapping("/{planIds}")
    public AjaxResult remove(@PathVariable Long[] planIds) {
        return toAjax(planNeedInfoService.deletePlanNeedInfoByPlanIds(planIds));
    }
}
